import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 物品交易服务对象基类
 *
 * @export
 * @class EMItemTradeServiceBase
 * @extends {EntityServie}
 */
export default class EMItemTradeServiceBase extends EntityService {

    /**
     * Creates an instance of  EMItemTradeServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  EMItemTradeServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof EMItemTradeServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='emitemtrade';
        this.APPDEKEY = 'emitemtradeid';
        this.APPDENAME = 'emitemtrades';
        this.APPDETEXT = 'emitemtradename';
        this.APPNAME = 'eamweb';
        this.SYSTEMNAME = 'eam_practice05';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/select`,isloading);
        }
        if(context.pfunit && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/select`,isloading);
        }
        if(context.pfemp && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/select`,isloading);
        }
        if(context.emstore && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/select`,isloading);
        }
        if(context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/select`,isloading);
        }
        if(context.emservice && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/select`,isloading);
        }
        if(context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/select`,isloading);
        }
            return Http.getInstance().get(`/emitemtrades/${context.emitemtrade}/select`,isloading);
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().put(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,data,isloading);
        }
        if(context.pfunit && context.emitem && context.emitemtrade){
            return Http.getInstance().put(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,data,isloading);
        }
        if(context.pfemp && context.emitem && context.emitemtrade){
            return Http.getInstance().put(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,data,isloading);
        }
        if(context.emstore && context.emitem && context.emitemtrade){
            return Http.getInstance().put(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,data,isloading);
        }
        if(context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().put(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,data,isloading);
        }
        if(context.emservice && context.emitem && context.emitemtrade){
            return Http.getInstance().put(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,data,isloading);
        }
        if(context.emitem && context.emitemtrade){
            return Http.getInstance().put(`/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/emitemtrades/${context.emitemtrade}`,data,isloading);
            return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/checkkey`,data,isloading);
        }
        if(context.pfunit && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/checkkey`,data,isloading);
        }
        if(context.pfemp && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/checkkey`,data,isloading);
        }
        if(context.emstore && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/checkkey`,data,isloading);
        }
        if(context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/checkkey`,data,isloading);
        }
        if(context.emservice && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/checkkey`,data,isloading);
        }
        if(context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/checkkey`,data,isloading);
        }
            return Http.getInstance().post(`/emitemtrades/${context.emitemtrade}/checkkey`,data,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades`,data,isloading);
        }
        if(context.pfunit && context.emitem && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades`,data,isloading);
        }
        if(context.pfemp && context.emitem && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades`,data,isloading);
        }
        if(context.emstore && context.emitem && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades`,data,isloading);
        }
        if(context.emstorepart && context.emitem && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades`,data,isloading);
        }
        if(context.emservice && context.emitem && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades`,data,isloading);
        }
        if(context.emitem && true){
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            return Http.getInstance().post(`/emitems/${context.emitem}/emitemtrades`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/emitemtrades`,data,isloading);
        return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().delete(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.pfunit && context.emitem && context.emitemtrade){
            return Http.getInstance().delete(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.pfemp && context.emitem && context.emitemtrade){
            return Http.getInstance().delete(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.emstore && context.emitem && context.emitemtrade){
            return Http.getInstance().delete(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().delete(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.emservice && context.emitem && context.emitemtrade){
            return Http.getInstance().delete(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.emitem && context.emitemtrade){
            return Http.getInstance().delete(`/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
            return Http.getInstance().delete(`/emitemtrades/${context.emitemtrade}`,isloading);

    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/save`,data,isloading);
        }
        if(context.pfunit && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/save`,data,isloading);
        }
        if(context.pfemp && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/save`,data,isloading);
        }
        if(context.emstore && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/save`,data,isloading);
        }
        if(context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/save`,data,isloading);
        }
        if(context.emservice && context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/save`,data,isloading);
        }
        if(context.emitem && context.emitemtrade){
            return Http.getInstance().post(`/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}/save`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/emitemtrades/${context.emitemtrade}/save`,data,isloading);
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && true){
            return Http.getInstance().get(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/getdraft`,isloading);
        }
        if(context.pfunit && context.emitem && true){
            return Http.getInstance().get(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades/getdraft`,isloading);
        }
        if(context.pfemp && context.emitem && true){
            return Http.getInstance().get(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades/getdraft`,isloading);
        }
        if(context.emstore && context.emitem && true){
            return Http.getInstance().get(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades/getdraft`,isloading);
        }
        if(context.emstorepart && context.emitem && true){
            return Http.getInstance().get(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/getdraft`,isloading);
        }
        if(context.emservice && context.emitem && true){
            return Http.getInstance().get(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades/getdraft`,isloading);
        }
        if(context.emitem && true){
            return Http.getInstance().get(`/emitems/${context.emitem}/emitemtrades/getdraft`,isloading);
        }
        let res:any = await  Http.getInstance().get(`/emitemtrades/getdraft`,isloading);
        res.data.emitemtrade = data.emitemtrade;
        return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.pfunit && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.pfemp && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.emstore && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.emstorepart && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.emservice && context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
        if(context.emitem && context.emitemtrade){
            return Http.getInstance().get(`/emitems/${context.emitem}/emitemtrades/${context.emitemtrade}`,isloading);
        }
            let res:any = await Http.getInstance().get(`/emitemtrades/${context.emitemtrade}`,isloading);
            return res;

    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/fetchdefault`,tempData,isloading);
        }
        if(context.pfunit && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades/fetchdefault`,tempData,isloading);
        }
        if(context.pfemp && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades/fetchdefault`,tempData,isloading);
        }
        if(context.emstore && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades/fetchdefault`,tempData,isloading);
        }
        if(context.emstorepart && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/fetchdefault`,tempData,isloading);
        }
        if(context.emservice && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades/fetchdefault`,tempData,isloading);
        }
        if(context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emitems/${context.emitem}/emitemtrades/fetchdefault`,tempData,isloading);
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/emitemtrades/fetchdefault`,tempData,isloading);
    }

    /**
     * FetchIndexDER接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EMItemTradeServiceBase
     */
    public async FetchIndexDER(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.emstore && context.emstorepart && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emstores/${context.emstore}/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/fetchindexder`,tempData,isloading);
        }
        if(context.pfunit && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/pfunits/${context.pfunit}/emitems/${context.emitem}/emitemtrades/fetchindexder`,tempData,isloading);
        }
        if(context.pfemp && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/pfemps/${context.pfemp}/emitems/${context.emitem}/emitemtrades/fetchindexder`,tempData,isloading);
        }
        if(context.emstore && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emstores/${context.emstore}/emitems/${context.emitem}/emitemtrades/fetchindexder`,tempData,isloading);
        }
        if(context.emstorepart && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emstoreparts/${context.emstorepart}/emitems/${context.emitem}/emitemtrades/fetchindexder`,tempData,isloading);
        }
        if(context.emservice && context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emservices/${context.emservice}/emitems/${context.emitem}/emitemtrades/fetchindexder`,tempData,isloading);
        }
        if(context.emitem && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/emitems/${context.emitem}/emitemtrades/fetchindexder`,tempData,isloading);
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/emitemtrades/fetchindexder`,tempData,isloading);
    }
}